@@ -328,7 +328,7 @@ def debug(txt_name, is_2D = None,clean = None, length = None, display = True):
         folder_path, validation_path, validation = core.resolve_txt_path_and_validation(txt_name)
         proposed_uncorrupted_data = wait_queue.wait_read(txt_name,debug=True)
         if proposed_uncorrupted_data:
-            cleaned_data = others.get_debug_record(proposed_uncorrupted_data, is_2D, length = 4, display = display)
+            cleaned_data = others.get_debug_record(proposed_uncorrupted_data, is_2D, length, display = display)
 
             if clean:
                 if display:
